library(microeco)
# load the example data; 16S rRNA gene amplicon sequencing dataset
#data(sample_info_16S)
#data(otu_table_16S)
#data(taxonomy_table_16S)
# use phylogenetic tree to calculate phylogeny-based alpha and beta metrics
#data(phylo_tree_16S)
# load the environmental data which is detached from sample table
#data(env_data_16S)
# use pipe operator in magrittr package
library(magrittr)
# set.seed is used to fix the random number generation to make the results repeatable
set.seed(123)
# make the plotting background same with the tutorial
library(ggplot2)
theme_set(theme_bw())
rm(list = ls ()) #TO REMOVE PREVIOUS ENVIRONMENT

data<- read.table("Map.txt", sep = "\t", row.names = 1, header = TRUE)# Metadata information
data2<- read.table("otu_table_urine.txt", sep = "\t", row.names = 1, header = TRUE)#Absolute abundance count
data3<- read.table("taxonomy.txt", sep = "\t", row.names = 1, header = TRUE)#Taxonomic information file Kingdom to species
# use phylogenetic tree to calculate phylogeny-based alpha and beta metrics
# Let's create a microtable object with more information
dataset <- microtable$new(sample_table = data, otu_table = data2, tax_table = data3)
data[1:5, ]
data2[1:5, ]
data3[1:5, ]
dataset
dataset$tax_table %<>% base::subset(Kingdom == "k__Archaea" | Kingdom == "k__Eukaryota")
dataset
# This will remove the lines containing the taxa word regardless of taxonomic ranks and ignoring word case in the tax_table.
# So if you want to filter some taxa not considerd pollutions, please use subset like the previous operation to filter tax_table.
dataset$filter_pollution(taxa = c("mitochondria", "chloroplast"))
print(dataset)
dataset$tidy_dataset()
print(dataset)
dataset$sample_sums() %>% range
# As an example, use 10000 sequences in each sample
dataset$rarefy_samples(sample.size = 8166)
# use default parameters
dataset$cal_abund()
dataset$cal_abund()
# return
dataset$taxa_abund
class(dataset$taxa_abund)
# show part of the relative abundance at Phylum level
dataset$taxa_abund$Phyla[1:5, 1:5]
dataset$save_abund(dirpath = "taxa_abund")

dataset1 <- dataset$merge_samples(use_group = "Age_Group")
# dataset1 is a new microtable object
# metastat analysis at Genus level
t1 <- trans_diff$new(dataset = dataset, method = "metastat", group = "Gender", metastat_taxa_level = "Species")
t1$res_metastat #is the result
write.table(t1$res_metastat, file = "Metastat/metastat_Species_UrinE_myco_Gender.txt")

# t1$res_metastat_group_matrix is the group comparisons order for plotting
# plot the first paired groups, choose_group = 3
t1$plot_metastat(use_number = 1:10, qvalue = 0.1, choose_group = 1)

ggsave("Metastat_myco/metastat_species_urine_mycobiome_GENDER.pdf", width = 20, height = 20, units = "cm")


dataset$cal_alphadiv(PD = FALSE)
class(dataset$alpha_diversity)
# save dataset$alpha_diversity to a directory
dataset$save_alphadiv(dirpath = "alpha_diversity")
# If you do not want to calculate unifrac metrics, use unifrac = FALSE
# require GUniFrac package installed
dataset$cal_betadiv(unifrac = FALSE)
# return dataset$beta_diversity
class(dataset$beta_diversity)
# save dataset$beta_diversity to a directory
dataset$save_betadiv(dirpath = "beta_diversity")
t1 <- trans_alpha$new(dataset = dataset, group = "Gender")
# return t1$alpha_stat
t1$alpha_stat[1:5, ]
t1$cal_diff(method = "KW")
# return t1$res_alpha_diff
t1$res_alpha_diff[1:5, ]
t1$cal_diff(method = "KW_dunn")
# return t1$res_alpha_diff
t1$res_alpha_diff[1:5, ]
t1$plot_alpha(add_letter = T, measure = "Chao1", use_boxplot = FALSE)
t1$plot_alpha(pair_compare = TRUE, measure = "Obs", shape = "Gender")
t1$plot_alpha(pair_compare = TRUE, measure = "Chao1", shape = "Gender")
ggsave("alpha_Chao1_control_urine_virome_Gender.pdf", width = 20, height = 30, units = "cm")
ggsave("alpha_simpson_control_gut.pdf", width = 20, height = 30, units = "cm")
t1$plot_alpha(add_letter = T, measure = "Observed", use_boxplot = FALSE)
t1$plot_alpha(pair_compare = TRUE, measure = "Observed", shape = "Group1")
ggsave("alpha_Observed_gp1.pdf", width = 20, height = 30, units = "cm")
t1$plot_alpha(add_letter = T, measure = "Shannon", use_boxplot = FALSE)
t1$plot_alpha(pair_compare = TRUE, measure = "Shannon", shape = "Group1")
ggsave("alpha_Shannon_gp1.pdf", width = 20, height = 30, units = "cm")
t1$plot_alpha(add_letter = T, measure = "Simpson", use_boxplot = FALSE)
t1$plot_alpha(pair_compare = TRUE, measure = "Simpson", shape = "Group1")
ggsave("alpha_Shannon_gp1.pdf", width = 20, height = 30, units = "cm")
ggsave("alpha_Simpson_gp1.pdf", width = 20, height = 30, units = "cm")
t1$plot_alpha(add_letter = T, measure = "Shannon", use_boxplot = FALSE)
t1$plot_alpha(pair_compare = TRUE, measure = "Shannon", shape = "Group1")
ggsave("alpha_Shannon_gp1.pdf", width = 20, height = 30, units = "cm")
t1 <- trans_alpha$new(dataset = dataset, group = "Gender")

# we first create an trans_beta object
# measure parameter can invoke the distance matrix of bray in dataset$beta_diversity
t1 <- trans_beta$new(dataset = dataset, group = "Age_Group", measure = "bray")
# we first create an trans_beta object
# measure parameter can invoke the distance matrix of bray in dataset$beta_diversity
t1 <- trans_beta$new(dataset = dataset, group = "Gender", measure = "bray")
# use PCoA as an example, PCA or NMDS is also available
t1$cal_ordination(ordination = "PCoA")
# t1$res_ordination is the ordination result list
class(t1$res_ordination)
# plot the PCoA result
t1$plot_ordination(plot_color = "Age_Group", plot_shape = "Age_Group", plot_group_ellipse = TRUE)
ggsave("PCoA_Bra_Gender_Gut_metagenome.pdf", width = 20, height = 30, units = "cm")
# we first create an trans_beta object
# measure parameter can invoke the distance matrix of bray in dataset$beta_diversity
?tras_beta
# we first create an trans_beta object
# measure parameter can invoke the distance matrix of bray in dataset$beta_diversity
?trans_beta
# we first create an trans_beta object
# measure parameter can invoke the distance matrix of bray in dataset$beta_diversity
t1 <- trans_beta$new(dataset = dataset, group = "Gender", measure = "bray")
# use PCoA as an example, PCA or NMDS is also available
t1$cal_ordination(ordination = "PCoA")
# t1$res_ordination is the ordination result list
class(t1$res_ordination)
# plot the PCoA result
t1$plot_ordination(color_values = RColorBrewer::brewer.pal(8, "Dark2"), plot_color = "Gender", shape_values = c(15,16,17), plot_shape = "Gender", plot_group_ellipse = TRUE)
ggsave("PCoA_Bra_Gut_virome_Gender_gp.pdf", width = 30, height = 20, units = "cm")
?trans
# calculate and plot sample distances within groups
t1$cal_group_distance()
t1$res_group_distance
t1$plot_group_distance(distance_pair_stat = TRUE)
ggsave("PCoA_Bray_StOOL_DM_group_Gender_Group.pdf", width = 30, height = 40, units = "cm")
?cal_group_distance
t1$cal_group_distance(within_group = FALSE)
t1$plot_group_distance(distance_pair_stat = TRUE)
ggsave("PCoA_Bra_StOOL_b_Wgroup_Distance.pdf", width = 80, height = 40, units = "cm")
# manova for all groups
t1$cal_manova(cal_manova_all = TRUE)
t1$res_manova$aov.tab
# manova for each paired groups
t1$cal_manova(cal_manova_paired = TRUE)
t1$res_manova
write.table(t1$res_manova, file = "manova_result_urine_bac_Gender.txt")

?trans_diff
# use Genus level for parameter taxa_level, if you want to use all taxa, change to "all"
# nresam = 1 and boots = 1 represent no bootstrapping and use all samples directly
t1 <- trans_diff$new(dataset = dataset, method = "lefse", group = "Group1", taxa_level = "Genus")
# t1$res_rf is the result stored in the object
# plot the result
t2 <- t1$plot_diff_abund(use_number = 1:30, only_abund_plot = FALSE)

gridExtra::grid.arrange(t2$p1, t2$p2, ncol=2, nrow = 1, widths = c(2,2))
# the middle asterisk represent the significances
ggsave("DAA_gp1_lefse.pdf", width = 80, height = 40, units = "cm")

color_palette_30 <- c("#4f9eff","#b0c8f4","#d766dd","#4434a3","#964ae2","#5ef9ef","#95f4c1","#a2d2e8","#ce8921","#b48eed","#6aa9c9","#7bf289","#89f96d","#fc6507","#2f8209","#7766c4","#bac4f4","#2a2087","#c8d65e","#334f9b","#1aba18","#9a54e5","#ffccef","#ed6157","#ea9364","#6ebc32","#b3baf9","#37efd0","#e86f7f","#41e25c")

# The groupmean parameter can be used to obtain the group-mean barplot.
t1 <- trans_abund$new(dataset = dataset, taxrank = "Species", ntaxa = 30, groupmean = "Age_Group")
g1 <- t1$plot_bar(others_color = "yellow", use_colors = color_palette_30, legend_text_italic = FALSE, xtext_size = 15,)
g1 + theme_classic() + theme(axis.title.y = element_text(size = 18))
ggsave("Age_gp_urine_bac_Species_barplot.pdf", width = 40, height = 20, units = "cm")
t1 <- trans_diff$new(dataset = dataset, method = "metastat", group = "Gender", metastat_taxa_level = "Phyla")